@@ -31,25 +31,6 @@
 
 @implementation MusicTab
 
-// init/dealloc
-
-- (id)init
-{
-	if (self = [super init])
-	{
-		
-		fileExtensionsToCodecsDictionary = [[NSDictionary alloc] initWithObjectsAndKeys:[NSNumber numberWithInt:CODEC_MP3],
-			@"mp3", [NSNumber numberWithInt:CODEC_WMA], @"wma", [NSNumber numberWithInt:CODEC_WAV], @"wav", nil];
-	}
-	return self;
-}
-
-- (void)dealloc
-{
-	[fileExtensionsToCodecsDictionary release];
-	[super dealloc];
-}
-
 /**********************/
 
 - (void)awakeFromNib
@@ -57,8 +38,6 @@
 	[super awakeFromNib];
 	
 	[self setCorrectView];		
-	
-	[njbTable setAllowedExtensions:[self allowedExtensions]];
 }
 
 - (NSString *)browserPathFromPreferences
@@ -66,13 +45,6 @@
 	return [preferences musicTabDir];
 }
 
-- (NSArray *)allowedExtensions
-{
-	NSArray *extensions = [NSArray arrayWithObjects:@"mp3", @"wma", @"wav", nil];
-	
-	return extensions;
-}
-
 - (void)onConnectAndActive
 {
 	[super onConnectAndActive];
@@ -126,7 +98,7 @@
 					break;
 					// codec
 				case 'c':
-					[filename appendString:[track codecString]];
+					[filename appendString:[track fileTypeString]];
 					break;
 				default:
 					// incorrect variable name so print nothing
@@ -182,7 +154,7 @@
 		}
 	}
 	
-	NSString *extension = [[NSString stringWithString:@"."] stringByAppendingString:[[track codecString] lowercaseString]];
+	NSString *extension = [[NSString stringWithString:@"."] stringByAppendingString:[[track fileTypeString] lowercaseString]];
 	
 	fullPath = [fullPath stringByAppendingString:extension];
 	
@@ -206,7 +178,7 @@
 	NSMutableArray *tasks = [[NSMutableArray alloc] initWithCapacity:2];
 	
 	// write track tag to file
-	if ([preferences writeTagAfterCopy] && [track codec] == CODEC_MP3)
+	if ([preferences writeTagAfterCopy] && [track fileType] == LIBMTP_FILETYPE_MP3)
 	{
 		NJBQueueItem *writeTag = [[NJBQueueItem alloc] initWithTarget:self withSelector:@selector(writeTagToFile:) withObject:track];
 		[writeTag setRunInMainThread:YES];
@@ -252,6 +224,10 @@
 {
 	if (![theNJB isConnected])
 		return;
+	
+	/*[track fileTypeFromExtension];
+	if ([theNJB isSupportedFileType*/
+	
 	NJBQueueItem *copyTrack = [[NJBQueueItem alloc] initWithTarget:self withSelector:@selector(uploadTrack:) withObject:track];
 	[copyTrack setStatus:STATUS_UPLOADING_TRACK];
 	
@@ -271,12 +247,14 @@
  */
 - (NJBTransactionResult *)uploadTrack:(Track *)track
 {
-	ID3Tagger *tagger = [[ID3Tagger alloc] init];
-	[tagger setFileExtensionsToCodecsDictionary:fileExtensionsToCodecsDictionary];
-	[tagger setFilename:[track fullPath]];
-	Track *trackWithTag = [tagger readTrack];
-	[track setValuesToTrack:trackWithTag];
-	[tagger release];
+	if (![preferences iTunesIntegration])
+	{
+		ID3Tagger *tagger = [[ID3Tagger alloc] init];
+		[tagger setFilename:[track fullPath]];
+		Track *trackWithTag = [tagger readTrack];
+		[track setValuesToTrack:trackWithTag];
+		[tagger release];
+	}
 	
 	return [theNJB uploadTrack:track];
 }
@@ -299,6 +277,7 @@
 	// item count anyway since it could be the iTunes table
 	if (activeObject != OBJECT_NJB_TABLE)
 	{
+		[self enableTransfers];
 		[self showItemCounts];
 		return;
 	}
@@ -355,12 +334,11 @@
 	objectToSaveTrack = OBJECT_FILE_BROWSER;
 	// unchanged tag edit will be lost
 	ID3Tagger *tagger = [[ID3Tagger alloc] initWithFilename:path];
-	[tagger setFileExtensionsToCodecsDictionary:fileExtensionsToCodecsDictionary];
 	[drawerController enableAll];
 	Track *track = [tagger readTrack];
 	[drawerController showTrack:track];
 	[tagger release];
-	if ([track codec] != CODEC_MP3)
+	if ([track fileType] != LIBMTP_FILETYPE_MP3)
 		[drawerController disableWrite];
 }
 
@@ -501,7 +479,6 @@
 		if (![browser isDirectory])
 		{
 			ID3Tagger *tagger = [[ID3Tagger alloc] initWithFilename:[browser path]];
-			[tagger setFileExtensionsToCodecsDictionary:fileExtensionsToCodecsDictionary];
 			[drawerController enableAll];
 			[drawerController showTrack:[tagger readTrack]];
 			[tagger release];
@@ -564,28 +541,26 @@
 	NSEnumerator *objectEnumerator = [tracksDictArray objectEnumerator];
 	while (thisTrackDict = [objectEnumerator nextObject])
 	{
-		NSString *codec = [thisTrackDict objectForKey:@"Kind"];
+		// note we can't use the Kind field of the dictionary because this is localized
+		// so we must use the filename extension to determine codec
 		 
-		// we can only work with MP3 files from iTunes so ignore others
-		if (codec != nil && ([codec isEqualToString:@"MPEG audio file"] || [codec isEqualToString:@"WAV audio file"] || [codec isEqualToString:@"Fichier audio WAV"]))
-		{
-			Track *track = [[Track alloc] init];
+		Track *track = [[Track alloc] init];
+		[track setFullPath:[[NSURL URLWithString:[thisTrackDict valueForKey:@"Location"]] relativePath]];
+		[track fileTypeFromExtension];
 		
-			[track setTitle:[thisTrackDict valueForKey:@"Name"]];
-			[track setAlbum:[thisTrackDict valueForKey:@"Album"]];
-			[track setArtist:[thisTrackDict valueForKey:@"Artist"]];
-			[track setGenre:[thisTrackDict valueForKey:@"Genre"]];
-			[track setFullPath:[[NSURL URLWithString:[thisTrackDict valueForKey:@"Location"]] relativePath]];
-			[track setLength:([[thisTrackDict valueForKey:@"Total Time"] unsignedLongValue] / 1000)];
-			[track setYear:[[thisTrackDict valueForKey:@"Year"] unsignedIntValue]];
-			[track setTrackNumber:[[thisTrackDict valueForKey:@"Track Number"] unsignedIntValue]];
-			[track setFilesize:[[thisTrackDict valueForKey:@"Size"] unsignedLongLongValue]];
-			[track setCodec:CODEC_MP3];
+		[track setTitle:[thisTrackDict valueForKey:@"Name"]];
+		[track setAlbum:[thisTrackDict valueForKey:@"Album"]];
+		[track setArtist:[thisTrackDict valueForKey:@"Artist"]];
+		[track setGenre:[thisTrackDict valueForKey:@"Genre"]];
+		[track setLength:([[thisTrackDict valueForKey:@"Total Time"] unsignedLongValue] / 1000)];
+		[track setYear:[[thisTrackDict valueForKey:@"Year"] unsignedIntValue]];
+		[track setTrackNumber:[[thisTrackDict valueForKey:@"Track Number"] unsignedIntValue]];
+		[track setFilesize:[[thisTrackDict valueForKey:@"Size"] unsignedLongLongValue]];
 			
-			[iTunesArrayController addObject:track];
-			[track release];
-		}
+		[iTunesArrayController addObject:track];
+		[track release];
 	}
+	
 	[self showItemCounts];
 }
 
@@ -603,16 +578,10 @@
 	{
 		[self copyTrackToNJB:currentTrack];
 	}
-	
-	// TODO: we will reread the track info from the ID3 tag rather than use iTunes tags
 }
 
 - (void)addTrackToiTunes:(Track *)track
 {
-	// iTunes only supports MP3 and WAV that we have support for
-	if ([track codec] != CODEC_MP3 && [track codec] != CODEC_WAV)
-		return;
-	
 	NSString *code = [NSString stringWithFormat:@" \
 	set filenameP to \"%@\"									\n \
 	set filenameAS to POSIX file filenameP	\n \
@@ -687,4 +656,17 @@
 	}
 }
 
+/* can we copy a file to the NJB? We override super so we can test to see if
+ * iTunes table has a selection
+ */
+- (BOOL)canCopyToNJB
+{
+	if (![theNJB isConnected])
+		return NO;
+	else if ([preferences iTunesIntegration])
+		return ([iTunesTable selectedRow] != -1);
+	else
+		return [super canCopyToNJB];
+}
+
 @end
\ No newline at end of file
