@@ -11,6 +11,7 @@
  * sorting and searching of the list.
  */
 
+#import "defs.h"
 #import "MyTableTab.h"
 
 @implementation MyTableTab
@@ -79,7 +80,7 @@
 
 - (void)showItemCounts
 {
-	NSString *selectedString = [NSString stringWithFormat:@"Selected %d out of %d", [njbTable numberOfSelectedRows], [[arrayController arrangedObjects] count]];
+	NSString *selectedString = [NSString stringWithFormat:NSLocalizedString(@"Selected %d out of %d", nil), [njbTable numberOfSelectedRows], [[arrayController arrangedObjects] count]];
 	[itemCountField setStringValue:selectedString];
 }
 
