@@ -5,7 +5,7 @@
 //  Created by Richard Low on Wed Jul 21 2004.
 //
 
-/* An obj-c wrapper for libnjb
+/* An obj-c wrapper for libnjb/libmtp
  * most methods return an NJBTransactionResult
  * to indicate success/failure
  */
@@ -24,7 +24,7 @@
 #import "UnicodeWrapper.h"
 
 // number of tracks in tracklist downloaded in between progress bar updates (MTP only)
-#define TRACKLIST_PROGRESS_UPDATE_INTERVAL	50
+#define TRACKLIST_PROGRESS_UPDATE_INTERVAL	10
 
 // declared so can be accessed from C function progress
 // set to be the outlet statusDisplayer in awakeFromNib
@@ -538,7 +538,7 @@ StatusDisplayer *statusDisplayerGlobal;
 	{		
 		NSDate *date = [NSDate date];
 				
-		LIBMTP_track_t *tracks = LIBMTP_Get_Tracklisting(device);
+		LIBMTP_track_t *tracks = LIBMTP_Get_Tracklisting_With_Callback(device, mtp_progress, &downloadingTracks);
 		if (tracks == NULL)
 		{
 			downloadingTracks = NO;
@@ -663,7 +663,7 @@ StatusDisplayer *statusDisplayerGlobal;
 		LIBMTP_track_t *trackmeta = [self libmtpTrack_tFromTrack:track];
 		if (trackmeta->filename != NULL)
 			free(trackmeta->filename);
-		trackmeta->filename = strdup(filename);
+		trackmeta->filename = strdup(lastPathComponent);
 		
 		if (LIBMTP_Send_Track_From_File(device, filename, trackmeta, mtp_progress, NULL, [self musicAssoc]) != 0)
 		{
@@ -941,7 +941,7 @@ StatusDisplayer *statusDisplayerGlobal;
 		
 		LIBMTP_file_t *files;
 		
-		files = LIBMTP_Get_Filelisting(device);
+		files = LIBMTP_Get_Filelisting_With_Callback(device, mtp_progress, &downloadingFiles);
 		if (files == NULL)
 		{
 			downloadingFiles = NO;
@@ -1475,6 +1475,12 @@ int progress(u_int64_t sent, u_int64_t total, const char* buf, unsigned len, voi
 
 int mtp_progress (uint64_t const sent, uint64_t const total, void const * const data)
 {
+  // if we're downloading a the file or track listing don't update on every file
+  if (data != NULL && *(BOOL*)data == YES)
+  {
+   if (sent % TRACKLIST_PROGRESS_UPDATE_INTERVAL != 0)
+    return 0;
+  }
 	double percent = (double)sent*100.0/(double)total;
 	[statusDisplayerGlobal updateTaskProgress:percent];
 	
