@@ -1,23 +1,21 @@
 #include "common.h"
+#include <libgen.h>
 
-int main (int argc, char **argv)
+void newfolder_function(char *);
+void newfolder_command(int,char **);
+
+extern LIBMTP_folder_t *folders;
+extern LIBMTP_file_t *files;
+extern LIBMTP_mtpdevice_t *device;
+
+void newfolder_command (int argc, char **argv)
 {
-  LIBMTP_mtpdevice_t *device;
   uint32_t newid;
   
   if(argc != 3) {
     printf("Usage: newfolder name id\n");
     printf("(id = parent folder or 0 to create the new folder in the root dir)\n");
-    return -1;
-  }
-  
-  LIBMTP_Init();
-
-  device = LIBMTP_Get_First_Device();
-
-  if (device == NULL) {
-    printf("No devices.\n");
-    exit (0);
+    return;
   }
   
   newid = LIBMTP_Create_Folder(device, argv[1], atol(argv[2]));
@@ -26,10 +24,20 @@ int main (int argc, char **argv)
   } else {
     printf("New folder created with ID: %d\n", newid);
   }
+}
 
-  LIBMTP_Release_Device(device);
-
-  printf("OK.\n");
-  exit (0);
+void
+newfolder_function(char * path)
+{
+  printf("Creating new folder %s\n",path);
+  char * parent = dirname(path);
+  char * folder = basename(path);
+  int id = parse_path (parent,files,folders);
+  int newid = LIBMTP_Create_Folder(device, folder, id);
+  if (newid == 0) {
+    printf("Folder creation failed.\n");
+  } else {
+    printf("New folder created with ID: %d\n", newid);
+  }
 }
 
