@@ -27,6 +27,9 @@
 #include "libusb-glue.h"
 #include "util.h"
 
+/* To enable debug prints, switch on this */
+//#define ENABLE_USB_BULK_DEBUG
+
 /* OUR APPLICATION USB URB (2MB) ;) */
 #define PTPCAM_USB_URB		2097152
 
@@ -72,8 +75,11 @@ static const LIBMTP_device_entry_t mtp_device_table[] = {
   { "Creative Zen Vision:M", 0x041e, 0x413e, DEVICE_FLAG_NONE },
   // Reported by marazm@o2.pl
   { "Creative Zen V", 0x041e, 0x4150, DEVICE_FLAG_NONE },
+  // Reported by danielw@iinet.net.au
+  { "Creative Zen Vision:M (DVP-HD0004)", 0x041e, 0x4151, DEVICE_FLAG_NONE },
   // Reported by Darel on the XNJB forums
-  { "Creative Zen V plus", 0x041e, 0x4152, DEVICE_FLAG_NONE },
+  { "Creative Zen V Plus", 0x041e, 0x4152, DEVICE_FLAG_NONE },
+  { "Creative Zen Vision W", 0x041e, 0x4153, DEVICE_FLAG_NONE },
 
   /*
    * Samsung
@@ -89,6 +95,10 @@ static const LIBMTP_device_entry_t mtp_device_table[] = {
   { "Samsung YP-U2J (YP-U2JXB/XAA)", 0x04e8, 0x5054, DEVICE_FLAG_NONE },
   // Reported by Andrew Benson
   { "Samsung YP-F2J", 0x04e8, 0x5057, DEVICE_FLAG_DUALMODE },
+  // Reported by Patrick <skibler@gmail.com>
+  { "Samsung YP-K5", 0x04e8, 0x505a, DEVICE_FLAG_NONE },
+  // Reported by Matthew Wilcox <matthew@wil.cx>
+  { "Samsung Yepp T9", 0x04e8, 0x507f, DEVICE_FLAG_NONE },
   // From a rouge .INF file
   { "Samsung YH-999 Portable Media Center", 0x04e8, 0x5a0f, DEVICE_FLAG_NONE },
 
@@ -104,13 +114,15 @@ static const LIBMTP_device_entry_t mtp_device_table[] = {
   { "JVC Alneo XA-HD500", 0x04f1, 0x6105, DEVICE_FLAG_NONE },
 
   /*
-   * Philipps
+   * Philips
    */
   // From libgphoto2 source
-  { "Philipps HDD6320", 0x0471, 0x01eb, DEVICE_FLAG_NONE },
-  { "Philipps HDD6320 2", 0x0471, 0x014b, DEVICE_FLAG_NONE },
+  { "Philips HDD6320", 0x0471, 0x01eb, DEVICE_FLAG_NONE },
+  { "Philips HDD6320/00", 0x0471, 0x014b, DEVICE_FLAG_NONE },
   // Anonymous SourceForge user
-  { "Philipps HDD1630/17", 0x0471, 0x014c, DEVICE_FLAG_NONE },
+  { "Philips HDD1630/17", 0x0471, 0x014c, DEVICE_FLAG_NONE },
+  // From Gerhard Mekenkamp
+  { "Philips GoGear Audio", 0x0471, 0x0165, DEVICE_FLAG_NONE },
 
   /*
    * SanDisk
@@ -126,23 +138,26 @@ static const LIBMTP_device_entry_t mtp_device_table[] = {
 
   /*
    * iRiver
+   * we assume that PTP_OC_MTP_GetObjPropList is essentially
+   * broken on all iRiver devices. Please test on your device
+   * if you believe it isn't!
    */
-  { "iRiver Portable Media Center", 0x1006, 0x4002, DEVICE_FLAG_NONE },
-  { "iRiver Portable Media Center", 0x1006, 0x4003, DEVICE_FLAG_NONE },
+  { "iRiver Portable Media Center", 0x1006, 0x4002, DEVICE_FLAG_BROKEN_MTPGETOBJPROPLIST },
+  { "iRiver Portable Media Center", 0x1006, 0x4003, DEVICE_FLAG_BROKEN_MTPGETOBJPROPLIST },
   // From libgphoto2 source
-  { "iRiver T10", 0x4102, 0x1113, DEVICE_FLAG_NONE },
-  { "iRiver T20 FM", 0x4102, 0x1114, DEVICE_FLAG_NONE },
-  { "iRiver U10", 0x4102, 0x1116, DEVICE_FLAG_NONE },
-  { "iRiver T10", 0x4102, 0x1117, DEVICE_FLAG_NONE },
-  { "iRiver T20", 0x4102, 0x1118, DEVICE_FLAG_NONE },
-  { "iRiver T30", 0x4102, 0x1119, DEVICE_FLAG_NONE },
+  { "iRiver T10", 0x4102, 0x1113, DEVICE_FLAG_BROKEN_MTPGETOBJPROPLIST },
+  { "iRiver T20 FM", 0x4102, 0x1114, DEVICE_FLAG_BROKEN_MTPGETOBJPROPLIST },
+  { "iRiver U10", 0x4102, 0x1116, DEVICE_FLAG_BROKEN_MTPGETOBJPROPLIST },
+  { "iRiver T10", 0x4102, 0x1117, DEVICE_FLAG_BROKEN_MTPGETOBJPROPLIST },
+  { "iRiver T20", 0x4102, 0x1118, DEVICE_FLAG_BROKEN_MTPGETOBJPROPLIST },
+  { "iRiver T30", 0x4102, 0x1119, DEVICE_FLAG_BROKEN_MTPGETOBJPROPLIST },
   // Reported by David Wolpoff
-  { "iRiver T10 2GB", 0x4102, 0x1120, DEVICE_FLAG_NONE },
+  { "iRiver T10 2GB", 0x4102, 0x1120, DEVICE_FLAG_BROKEN_MTPGETOBJPROPLIST },
   // Reported by Adam Torgerson
-  { "iRiver Clix", 0x4102, 0x112a, DEVICE_FLAG_NONE },
+  { "iRiver Clix", 0x4102, 0x112a, DEVICE_FLAG_BROKEN_MTPGETOBJPROPLIST },
   // Reported by Scott Call
-  { "iRiver H10 20GB", 0x4102, 0x2101, DEVICE_FLAG_NONE },
-  { "iRiver H10", 0x4102, 0x2102, DEVICE_FLAG_NONE },
+  { "iRiver H10 20GB", 0x4102, 0x2101, DEVICE_FLAG_BROKEN_MTPGETOBJPROPLIST },
+  { "iRiver H10", 0x4102, 0x2102, DEVICE_FLAG_BROKEN_MTPGETOBJPROPLIST },
 
   /*
    * Dell
@@ -383,6 +398,10 @@ ptp_read_func (unsigned char *bytes, unsigned int size, void *data, unsigned int
     }
     if (result < 0)
       return PTP_ERROR_IO;
+#ifdef ENABLE_USB_BULK_DEBUG
+    printf("<==USB IN\n");
+    data_dump_ascii (stdout,(bytes+curread),result,16);
+#endif
     curread += result;
     if (result < toread) /* short reads are common */
       break;
@@ -430,6 +449,10 @@ ptp_write_func (unsigned char *bytes, unsigned int size, void *data)
     if (towrite > CONTEXT_BLOCK_SIZE)
       towrite = CONTEXT_BLOCK_SIZE;
     result=USB_BULK_WRITE(ptp_usb->handle,ptp_usb->outep,(char *)(bytes+curwrite),towrite,ptpcam_usb_timeout);
+#ifdef ENABLE_USB_BULK_DEBUG
+    printf("USB OUT==>\n");
+    data_dump_ascii (stdout,(bytes+curwrite),towrite,16);
+#endif
     if (result < 0)
       return PTP_ERROR_IO;
     curwrite += result;
@@ -708,6 +731,20 @@ next_step:
   }
   
   ret = ptp_opensession(params,1);
+
+  // This works in situations where previous bad applications have not used LIBMTP_Release_Device on exit
+  if (ret == PTP_ERROR_IO) {
+	printf("%s\n","PTP ERROR IO: Trying again after resetting USB");
+        // printf("%s\n","Closing USB interface...");
+	close_usb(ptp_usb,dev->config->interface->altsetting->bInterfaceNumber);
+        // printf("%s\n","Init PTP USB...");
+	if (init_ptp_usb(params, ptp_usb, dev) < 0) {
+ 	   return PTP_CD_RC_ERROR_CONNECTING;
+  	}
+	
+	ret = ptp_opensession(params,1);
+  }
+
   // printf("Session open (%d)...\n", ret);
   if (ret == PTP_RC_InvalidTransactionID) {
     params->transaction_id += 10;
