@@ -44,8 +44,7 @@ static njb_device_entry_t njb_device_table[] = {
   { "Second Generation Dell DJ", 0x041e, 0x4126, NJB_PROTOCOL_PDE, 1, NJB_DEVICE_DELLDJ2 },
   { "Dell Pocket DJ", 0x041e, 0x4127, NJB_PROTOCOL_PDE, 1, NJB_DEVICE_POCKETDJ },
   { "Creative Zen Sleek", 0x041e, 0x4136, NJB_PROTOCOL_PDE, 1, NJB_DEVICE_ZENSLEEK },
-  { "Creative Zen (Micro variant)", 0x041e, 0x411d, NJB_PROTOCOL_PDE, 1, NJB_DEVICE_CREATIVEZEN },
-  { "Third Generation Dell DJ", 0x041e, 0x412f, NJB_PROTOCOL_PDE, 1, NJB_DEVICE_DELLDJ3 }
+  { "Creative Zen (Micro variant)", 0x041e, 0x411d, NJB_PROTOCOL_PDE, 1, NJB_DEVICE_CREATIVEZEN }
 };
 static const int njb_device_table_size = sizeof(njb_device_table) / sizeof(njb_device_entry_t);
 
